@@ -1,11 +1,22 @@
+import logging
+
 from rest_framework import permissions
 
+logger = logging.getLogger()
 
 class IsAuthenticated(permissions.BasePermission):
     def has_permission(self, request, view):
         """
         Allows access only to authenticated users with uid.
         """
+        if request.user:
+            if request.user.keys():
+                logger.info(f'Verifing permissions for user {request.user} with keys {request.user.keys()}')
+            else:
+                logger.info(f'Verifing permissions for user {request.user} with no keys')
+        else:
+            logger.info(f'No request.user found for this request: {request}')
+
         return bool(request.user and 'uid' in request.user.keys())
 
 
@@ -55,6 +66,6 @@ class IsCustomUserPermission(permissions.BasePermission):
             try:
                 if name == request.user['name']:
                     return True
-            except KeyError:
+            except (KeyError, TypeError):
                 return False
         return False
